@@ -37,10 +37,12 @@ mkdir tests
 pushd tests
 
 cat > manifest.json <<EOF
-{  
+{   /* comment here! */
   "remotes":
     {"origin": { "fetch": "$TESTDIR/%(name)s" }},
- 
+/* multi
+line
+comment*/
   "projects":
     {"repo_a": { "track-tag": "commit_b" }}
 }
@@ -50,7 +52,7 @@ $CREPO sync
 
 ## Check that the checkout is correct
 pushd repo_a
-test $(git symbolic-ref HEAD) == "refs/heads/commit_b"
+test "$(git symbolic-ref HEAD)" == "refs/heads/commit_b"
 test $(git remote) == "origin"
 test -f file_a
 popd
